==> menu-1.0.17.zip: src/readme.md <==
# Menu API Interface Specification

---

## Overview

This document outlines the API contract for managing menu configurations in the system. It includes endpoints for creating, updating, deleting, viewing, and duplicating menu entries (`menu_menus`). All requests are processed through a single PHP entry point (`function.php`) using `POST` requests, with operations determined by the `action` field in the payload.

---

## API Summary Table

| Action                        | Method    | Auth Required | Payload Object                                            | Description                                                     |
|-------------------------------|-----------|---------------|-----------------------------------------------------------|-----------------------------------------------------------------|
| `insertIntoMenuMenus`         | POST      | Yes           | `menuMenus`                                               | Insert a new menu item                                          |
| `insertIntoMenuCategories`    | POST      | Yes           | `menuCategories`                                          | Insert a new Categories                                         |
| `insertItemIntoMenu`          | POST      | Yes           | `menuItems`                                               | Insert a new Categories                                         |
| `insertItemIntoMenuCategory`  | POST      | Yes           | `menuCategoryItems`                                       | Insert a link between an item and a Category                    |
| `insertMenuOptionsSet`        | POST      | Yes           | `menuOptionGroups`, `menuOptionExtra`, `menuOptionJoins`  | Insert a link between an item and options and option items      |
| `insertMenuOptionExtra`       | POST      | Yes           | `menuOptionExtra`                                         | Insert a option items                                           |
| `insertMenuOptionJoins`       | POST      | Yes           | `menuOptionJoins`                                         | Insert a linki to an option group and item option               |
| `updateMenuMenus`             | POST      | Yes           | `menuMenus`                                               | Update an existing menu item                                    |
| `updateMenuCategories`        | POST      | Yes           | `categories`                                              | Update an existing Categories                                   |
| `updateMenuItems`             | POST      | Yes           | `items`                                                   | Update an existing item                                         |
| `updateMenuCategoryItems`     | POST      | Yes           | `categoryItems`                                           | Update the active status                                        |
| `updateMenuOptionGroup`       | POST      | Yes           | `optionGroups`                                            | Update the opton values                                         |
| `updateMenuOptionExtra`       | POST      | Yes           | `optionExtra`                                             | Update the option item values                                   |
| `updateMenuOptionJoins`       | POST      | Yes           | `optionJoins`                                             | Update the option item values                                   |
| `deleteMenuMenus`             | POST      | Yes           | `menuMenus`                                               | Soft-delete a menu                                              |
| `deleteMenuCategories`        | POST      | Yes           | `categories`                                              | Soft-delete a menu Categories items                             |
| `deleteMenuItems`             | POST      | Yes           | `items`                                                   | Soft-delete a items                                             |
| `deleteMenuCategoryItems`     | POST      | Yes           | `categoryItems`                                           | Soft-delete a category Items                                    |
| `deleteMenuOptionExtra`       | POST      | Yes           | `optionItems`                                             | Soft-delete a option Items                                      |
| `deleteMenuOptionGroup`       | POST      | Yes           | `optionGroups`                                            | Soft-delete a option group                                      |
| `deleteMenuOptionJoins`       | POST      | Yes           | `optionJoins`                                             | Soft-delete a join group                                        |
| ~~`viewMenuMenus`~~           |~~ GET ~~ | ~~No~~         | —                                                         | ~~View menu items available to the user's role and tenant~~     |
| `viewSuperAdminMenus`         | GET       | Yes           | —                                                         | View Menu  __(Not Implemented -- Subject to change WFWU)__      |
| `viewAdminMenus`              | GET       | Yes           | —                                                         | View Menu  __(Not Implemented -- Subject to changeW FWU)__      |
| `viewPublicMenus`             | GET       | No            | —                                                         | View Menu  __(Not Implemented -- Subject to change WFWU)__      |
| `duplicateMenuMenus`          | POST      | Yes           | `menuMenus`                                               | Duplicate a menu by ID (Owner only)   __(Not Implemented)__     |

---

## Payload Structures

### `insertIntoMenuMenus`
```json
{
  "action": "insertIntoMenuMenus",
  "menuMenus": {
    "name": "Main Menu",
    "description": "Primary navigation",
    "isActive": 1,
  }
}
```

### `insertIntoMenuCategories`
```json
{
  "action": "insertIntoMenuCategories",
  "menuCategories": {
    "menuId":       int,
    "parentId":     int optional,
    "name":         string,
    "description":  string,
    "isActive" :    int (0,1),
    "sortOrder" :   int optional,
    "isDeleted" :   int (0,1) optional
  }
}
```

### `insertItemIntoMenu`
```json
{
  "action": "insertItemIntoMenu", // Suggested otherwise this item is not linked to a menu and will be need to be linked another way
  "menuItems": {
    "menuId":       int,
    "categoryId":   int,
    "name":         string,
    "description":  string,
    "basePrice" :   decimal,
    "isActive" :    int optional,
  }
}
```

### `insertItemIntoMenuCategory`
```json
{
  "action": "insertItemIntoMenuCategory",
  "menuCategoryItems": {
    "categoryId": int,
    "itemId":     int
  }
}
```

### `insertMenuOptionsSet`
```json
{
  "action": "insertMenuOptionsSet",
  "menuOptionGroups": {
    "itemId":           int,
    "groupName":        string,
    "groupDescription": string,
    "minSelect":        int,      // Minumun that can be selcted in the grouping  
    "maxSelect":        int,      // Maximun that can be selcted in the grouping  
    "isActive":         int
  },
  "menuOptionExtra": { // optional 
      {
          "extraName":         string,
          "extraDescription":  string,
          "isDefault":          int,
          "allowToggleOnly"     int,
          "optionPrice":        decimal,
          "isActive":           int
      },{
          "extraName":         string,
          "extraDescription":  string,
          "isDefault":          int,
          "allowToggleOnly"     int,
          "optionPrice":        decimal,
          "isActive":           int
      },
      {...},
  },
  "menuOptionJoins":{ // optional
    {
      "extraId":    int
      "isActive":   int //optional  
    },
    {...}
  }
}
```

### `insertMenuOptionExtra`
```json
{
  "action": "insertMenuOptionExtra",
  "menuOptionItems": {
    "extraName":          string,
    "extraDescription":   string,
    "isDefault":          int,
    "allowToggleOnly"     int,
    "optionPrice":        decimal,
    "isActive":           int
  }
}
```

### `insertMenuOptionJoins`
```json
{
  "action": "insertMenuOptionJoins",
  "menuOptionJoins": {
    "extraId":    int,
    "optionId":   int,
    "isActive":   int
  }
}
```


### `updateMenuMenus`
```json
{
  "action": "updateMenuMenus",
  "menus": {
    "id":           int,
    "name":         string optional,
    "description":  string optional,
    "isActive":     int    optional,
  }
}
```

### `updateMenuCategories`
```json
{
  "action": "updateMenuCategories",
  "categories": {
    "id":           int,
    "menuId":       int    optional,  
    "parentId":     int    optional,
    "name":         string optional,
    "description":  string optional,
    "isActive":     int    optional,
  }
}
```

### `updateMenuItems`
```json
{
  "action": "updateMenuItems",
  "items": {
    "id":               int,
    "categoryId":       int     optional,
    "itemName":         string  optional,
    "itemDescription":  string  optional,
    "basePrice" :       decimal optional,
    "isActive" :        int     optional,
  }
}
```

### `updateMenuCategoryItems`
```json
{
  "action": "updateMenuCategoryItems",
  "categoryItems": {
    "id":       int,
    "isActive": int (0|1),
  }
}
```

### `updateMenuOptionGroup`
```json
{
  "action": "updateMenuOptionGroup",
  "optionGroups": {
    "id":               int,
    "groupName":        string optional,
    "groupDescription": string optional,
    "minSelect":        int optional,
    "maxSelect":        int optional,
    "isActive":         int (0|1) int optional
  }
}
```

### `updateMenuOptionExtra`
```json
{
  "action": "updateMenuOptionExtra",
  "optionExtra": {
    "id":                 int,
    "extraName":          string    optional,
    "extraDiscription":   string    optional,
    "isDefault":          int       optional,
    "allowToggleOnly"     int       optional,
    "optionPrice":        decimal   optional,
    "isActive":           int (0|1) optional, 
  }
}
```

### `updateMenuOptionJoins`
```json
{
  "action": "optionJoins",
  "categoryItems": {
    "id":       int,
    "isActive": int (0|1),
  }
}
```

### `deleteMenuMenus`
```json
{
  "action": "deleteMenuMenus",
  "menuMenus": {
    "id": int
  }
}
```

### `deleteMenuCategories`
```json
{
  "action": "deleteMenuCategories",
  "categories": {
    "id": int
  }
}
```

### `deleteMenuItems`
```json
{
  "action": "deleteMenuItems",
  "items": {
    "id": int
  }
}
```

### `deleteMenuCategoryItems`
```json
{
  "action": "deleteMenuCategoryItems",
  "categories": {
    "id": int
  }
}
```

### `deleteMenuOptionItem`
```json
{
  "action": "deleteMenuOptionItem",
  "optionItems": {
    "id": int
  }
}
```

### `deleteMenuOptionGroup`
```json
{
  "action": "deleteMenuOptionGroup",
  "optionGroups": {
    "id": int
  }
}
```

### `viewSuperAdminMenus`
```json
{
  "action": "viewSuperAdminMenus"
}
```

### `viewAdminMenus`
```json
{
  "action": "viewAdminMenus"
}
```

### `viewPublicMenus`
```json
{
  "action": "viewPublicMenus"
}
```

### `viewMenuMenus`
```json
{
  "action": "viewMenuMenus"
}
```

### `duplicateMenuMenus`
```json
{
  "action": "duplicateMenuMenus",
  "menuMenus": {
    "menueId": 7
  }
}
```

---

## Response Format

### Success
```json
{
  "status": "success",
  "message": "Record inserted successfully"
}
```

### Failure
```json
{
  "status": "failed",
  "message": "Access denied: insufficient permissions"
}
```

---

## Permissions and Role Behavior

| Role         | Can Insert | Can Update | Can Delete | Can View | Can Duplicate |
|--------------|------------|------------|------------|----------|---------------|
| Owner (4)    | ✅         | ✅         | ✅         | ✅       | ✅            |
| SysAdmin (1) | ❌         | ❌         | ❌         | ✅       | ❌            |
| Public (0)   | ❌         | ❌         | ❌         | ✅ (limited) | ❌        |

- All actions require the user to be authenticated and belong to a valid tenant.
- Insert/update/delete actions log entries into `menu_history` for auditing.

---

## Notes

- Menu items are soft-deleted by setting the `is_deleted` flag.
- `themeStatus` is optional and only used when applicable.
- Update and delete operations require the `id` field.
- Owner role has full CRUD access; other roles have restrictions.
- Returned timestamps (`createdAt`, `updatedAt`) are dynamic and ISO formatted.
- Duplicate and insert actions will return specific error messages if permissions are insufficient.

---


__WFWU__ will feck with you 
_End of Document_

==> menu-1.0.23.zip: src/readme.md <==
# Menu API Interface Specification

---

## Overview

This document outlines the API contract for managing menu configurations in the system. It includes endpoints for creating, updating, deleting, viewing, and duplicating menu entries (`menu_menus`). All requests are processed through a single PHP entry point (`function.php`) using `POST` requests, with operations determined by the `action` field in the payload.

---

## API Summary Table

| Action                        | Method    | Auth Required | Payload Object                                            | Description                                                     |
|-------------------------------|-----------|---------------|-----------------------------------------------------------|-----------------------------------------------------------------|
| `insertIntoMenuMenus`         | POST      | Yes           | `menuMenus`                                               | Insert a new menu item                                          |
| `insertIntoMenuCategories`    | POST      | Yes           | `menuCategories`                                          | Insert a new Categories                                         |
| `insertItemIntoMenu`          | POST      | Yes           | `menuItems`                                               | Insert a new Categories                                         |
| `insertItemIntoMenuCategory`  | POST      | Yes           | `menuCategoryItems`                                       | Insert a link between an item and a Category                    |
| `insertMenuOptionsSet`        | POST      | Yes           | `menuOptionGroups`, `menuOptionExtra`, `menuOptionJoins`  | Insert a link between an item and options and option items      |
| `insertMenuOptionExtra`       | POST      | Yes           | `menuOptionExtra`                                         | Insert a option items                                           |
| `insertMenuOptionJoins`       | POST      | Yes           | `menuOptionJoins`                                         | Insert a linki to an option group and item option               |
| `updateMenuMenus`             | POST      | Yes           | `menuMenus`                                               | Update an existing menu item                                    |
| `updateMenuCategories`        | POST      | Yes           | `categories`                                              | Update an existing Categories                                   |
| `updateMenuItems`             | POST      | Yes           | `items`                                                   | Update an existing item                                         |
| `updateMenuCategoryItems`     | POST      | Yes           | `categoryItems`                                           | Update the active status                                        |
| `updateMenuOptionGroup`       | POST      | Yes           | `optionGroups`                                            | Update the opton values                                         |
| `updateMenuOptionExtra`       | POST      | Yes           | `optionExtra`                                             | Update the option item values                                   |
| `updateMenuOptionJoins`       | POST      | Yes           | `optionJoins`                                             | Update the option item values                                   |
| `deleteMenuMenus`             | POST      | Yes           | `menuMenus`                                               | Soft-delete a menu                                              |
| `deleteMenuCategories`        | POST      | Yes           | `categories`                                              | Soft-delete a menu Categories items                             |
| `deleteMenuItems`             | POST      | Yes           | `items`                                                   | Soft-delete a items                                             |
| `deleteMenuCategoryItems`     | POST      | Yes           | `categoryItems`                                           | Soft-delete a category Items                                    |
| `deleteMenuOptionExtra`       | POST      | Yes           | `optionItems`                                             | Soft-delete a option Items                                      |
| `deleteMenuOptionGroup`       | POST      | Yes           | `optionGroups`                                            | Soft-delete a option group                                      |
| `deleteMenuOptionJoins`       | POST      | Yes           | `optionJoins`                                             | Soft-delete a join group                                        |
| ~~`viewMenuMenus`~~           |~~ GET ~~ | ~~No~~         | —                                                         | ~~View menu items available to the user's role and tenant~~     |
| `viewSuperAdminMenus`         | GET       | Yes           | —                                                         | View Menu  __(Not Implemented -- Subject to change WFWU)__      |
| `viewAdminMenus`              | GET       | Yes           | —                                                         | View Menu  __(Not Implemented -- Subject to changeW FWU)__      |
| `viewPublicMenus`             | GET       | No            | —                                                         | View Menu  __(Not Implemented -- Subject to change WFWU)__      |
| `duplicateMenuMenus`          | POST      | Yes           | `menuMenus`                                               | Duplicate a menu by ID (Owner only)   __(Not Implemented)__     |

---

## Payload Structures

### `insertIntoMenuMenus`
```json
{
  "action": "insertIntoMenuMenus",
  "menuMenus": {
    "name": "Main Menu",
    "description": "Primary navigation",
    "isActive": 1,
  }
}
```

### `insertIntoMenuCategories`
```json
{
  "action": "insertIntoMenuCategories",
  "menuCategories": {
    "menuId":       int,
    "parentId":     int optional,
    "name":         string,
    "description":  string,
    "isActive" :    int (0,1),
    "sortOrder" :   int optional,
    "isDeleted" :   int (0,1) optional
  }
}
```

### `insertItemIntoMenu`
```json
{
  "action": "insertItemIntoMenu", // Suggested otherwise this item is not linked to a menu and will be need to be linked another way
  "menuItems": {
    "menuId":       int,
    "categoryId":   int,
    "name":         string,
    "description":  string,
    "basePrice" :   decimal,
    "isActive" :    int optional,
  }
}
```

### `insertItemIntoMenuCategory`
```json
{
  "action": "insertItemIntoMenuCategory",
  "menuCategoryItems": {
    "categoryId": int,
    "itemId":     int
  }
}
```

### `insertMenuOptionsSet`
```json
{
  "action": "insertMenuOptionsSet",
  "menuOptionGroups": {
    "itemId":           int,
    "groupName":        string,
    "groupDescription": string,
    "minSelect":        int,      // Minumun that can be selcted in the grouping  
    "maxSelect":        int,      // Maximun that can be selcted in the grouping  
    "isActive":         int
  },
  "menuOptionExtra": { // optional 
      {
          "extraName":         string,
          "extraDescription":  string,
          "isDefault":         int,
          "allowToggleOnly"    int,
          "priceAdjustment":   decimal,
          "isActive":          int
      },{
          "extraName":         string,
          "extraDescription":  string,
          "isDefault":         int,
          "allowToggleOnly"    int,
          "priceAdjustment":   decimal,
          "isActive":          int
      },
      {...},
  },
  "menuOptionJoins":{ // optional
    {
      "extraId":    int
      "isActive":   int //optional  
    },
    {...}
  }
}
```

### `insertMenuOptionExtra`
```json
{
  "action": "insertMenuOptionExtra",
  "menuOptionExtra": {
    "extraName":          string,
    "extraDescription":   string,
    "isDefault":          int,
    "allowToggleOnly"     int,
    "priceAdjustment":    decimal,
    "isActive":           int
  }
}
```

### `insertMenuOptionJoins`
```json
{
  "action": "insertMenuOptionJoins",
  "menuOptionJoins": {
    "extraId":    int,
    "groupId":    int,
    "isActive":   int
  }
}
```


### `updateMenuMenus`
```json
{
  "action": "updateMenuMenus",
  "menus": {
    "id":           int,
    "name":         string optional,
    "description":  string optional,
    "isActive":     int    optional,
  }
}
```

### `updateMenuCategories`
```json
{
  "action": "updateMenuCategories",
  "categories": {
    "id":           int,
    "menuId":       int    optional,  
    "parentId":     int    optional,
    "name":         string optional,
    "description":  string optional,
    "isActive":     int    optional,
  }
}
```

### `updateMenuItems`
```json
{
  "action": "updateMenuItems",
  "items": {
    "id":               int,
    "categoryId":       int     optional,
    "itemName":         string  optional,
    "itemDescription":  string  optional,
    "basePrice" :       decimal optional,
    "isActive" :        int     optional,
  }
}
```

### `updateMenuCategoryItems`
```json
{
  "action": "updateMenuCategoryItems",
  "categoryItems": {
    "id":       int,
    "isActive": int (0|1),
  }
}
```

### `updateMenuOptionGroup`
```json
{
  "action": "updateMenuOptionGroup",
  "optionGroups": {
    "id":               int,
    "groupName":        string optional,
    "groupDescription": string optional,
    "minSelect":        int optional,
    "maxSelect":        int optional,
    "isActive":         int (0|1) int optional
  }
}
```

### `updateMenuOptionExtra`
```json
{
  "action": "updateMenuOptionExtra",
  "optionExtra": {
    "id":                 int,
    "extraName":          string    optional,
    "extraDiscription":   string    optional,
    "isDefault":          int       optional,
    "allowToggleOnly"     int       optional,
    "priceAdjustment":        decimal   optional,
    "isActive":           int (0|1) optional, 
  }
}
```

### `updateMenuOptionJoins`
```json
{
  "action": "optionJoins",
  "categoryItems": {
    "id":       int,
    "isActive": int (0|1),
  }
}
```

### `deleteMenuMenus`
```json
{
  "action": "deleteMenuMenus",
  "menus": {
    "id": int
  }
}
```

### `deleteMenuCategories`
```json
{
  "action": "deleteMenuCategories",
  "categories": {
    "id": int
  }
}
```

### `deleteMenuItems`
```json
{
  "action": "deleteMenuItems",
  "items": {
    "id": int
  }
}
```

### `deleteMenuCategoryItems`
```json
{
  "action": "deleteMenuCategoryItems",
  "categories": {
    "id": int
  }
}
```

### `deleteMenuOptionItem`
```json
{
  "action": "deleteMenuOptionItem",
  "optionItems": {
    "id": int
  }
}
```

### `deleteMenuOptionGroup`
```json
{
  "action": "deleteMenuOptionGroup",
  "optionGroups": {
    "id": int
  }
}
```

### `viewSuperAdminMenus`
```json
{
  "action": "viewSuperAdminMenus"
}
```

### `viewAdminMenus`
```json
{
  "action": "viewAdminMenus"
}
```

### `viewPublicMenus`
```json
{
  "action": "viewPublicMenus"
}
```

### `viewMenuMenus`
```json
{
  "action": "viewMenuMenus"
}
```

### `duplicateMenuMenus`
```json
{
  "action": "duplicateMenuMenus",
  "menuMenus": {
    "menueId": 7
  }
}
```

---

## Response Format

### Success
```json
{
  "status": "success",
  "message": "Record inserted successfully"
}
```

### Failure
```json
{
  "status": "failed",
  "message": "Access denied: insufficient permissions"
}
```

---

## Permissions and Role Behavior

| Role         | Can Insert | Can Update | Can Delete | Can View | Can Duplicate |
|--------------|------------|------------|------------|----------|---------------|
| Owner (4)    | ✅         | ✅         | ✅         | ✅       | ✅            |
| SysAdmin (1) | ❌         | ❌         | ❌         | ✅       | ❌            |
| Public (0)   | ❌         | ❌         | ❌         | ✅ (limited) | ❌        |

- All actions require the user to be authenticated and belong to a valid tenant.
- Insert/update/delete actions log entries into `menu_history` for auditing.

---

## Notes

- Menu items are soft-deleted by setting the `is_deleted` flag.
- `themeStatus` is optional and only used when applicable.
- Update and delete operations require the `id` field.
- Owner role has full CRUD access; other roles have restrictions.
- Returned timestamps (`createdAt`, `updatedAt`) are dynamic and ISO formatted.
- Duplicate and insert actions will return specific error messages if permissions are insufficient.

---


__WFWU__ will feck with you 
_End of Document_
